==> defguard-1.4.0.tar.gz: defguard-1.4.0/web/src/shared/validators.ts <==
import ipaddr from 'ipaddr.js';
import { z } from 'zod';

import { patternValidDomain, patternValidWireguardKey } from './patterns';

export const validateWireguardPublicKey = (props: {
  requiredError: string;
  minError: string;
  maxError: string;
  validKeyError: string;
}) =>
  z
    .string({
      invalid_type_error: props.requiredError,
      required_error: props.requiredError,
    })
    .min(44, props.minError)
    .max(44, props.maxError)
    .regex(patternValidWireguardKey, props.validKeyError);

// Returns false when invalid
export const validateIpOrDomain = (
  val: string,
  allowMask = false,
  allowIPv6 = false,
): boolean => {
  return (
    (allowIPv6 && validateIPv6(val, allowMask)) ||
    validateIPv4(val, allowMask) ||
    patternValidDomain.test(val)
  );
};

// Returns false when invalid
export const validateIpList = (
  val: string,
  splitWith = ',',
  allowMasks = false,
): boolean => {
  return val
    .replace(' ', '')
    .split(splitWith)
    .every((el) => {
      return validateIPv4(el, allowMasks) || validateIPv6(el, allowMasks);
    });
};

// Returns false when invalid
export const validateIpOrDomainList = (
  val: string,
  splitWith = ',',
  allowMasks = false,
  allowIPv6 = false,
): boolean => {
  const trimmed = val.replace(' ', '');
  const split = trimmed.split(splitWith);
  for (const value of split) {
    if (
      !validateIPv4(value, allowMasks) &&
      !patternValidDomain.test(value) &&
      (!allowIPv6 || !validateIPv6(value, allowMasks))
    ) {
      return false;
    }
  }
  return true;
};

// Returns false when invalid
export const validateIPv4 = (ip: string, allowMask = false): boolean => {
  if (allowMask) {
    if (ip.includes('/')) {
      return ipaddr.IPv4.isValidCIDR(ip);
    }
  }
  return ipaddr.IPv4.isValid(ip);
};

export const validateIPv6 = (ip: string, allowMask = false): boolean => {
  if (allowMask) {
    if (ip.includes('/')) {
      return ipaddr.IPv6.isValidCIDR(ip);
    }
  }
  return ipaddr.IPv6.isValid(ip);
};

export const validatePort = (val: string) => {
  const parsed = parseInt(val);
  if (!isNaN(parsed)) {
    return parsed <= 65535;
  }
};

export const numericString = (val: string) => /^\d+$/.test(val);

export const numericStringFloat = (val: string) => /^\d*\.?\d+$/.test(val);

==> defguard-1.5.1.tar.gz: defguard-1.5.1/web/src/shared/validators.ts <==
import ipaddr from 'ipaddr.js';
import { z } from 'zod';

import { patternValidDomain, patternValidWireguardKey } from './patterns';

export const validateWireguardPublicKey = (props: {
  requiredError: string;
  minError: string;
  maxError: string;
  validKeyError: string;
}) =>
  z
    .string({
      invalid_type_error: props.requiredError,
      required_error: props.requiredError,
    })
    .min(44, props.minError)
    .max(44, props.maxError)
    .regex(patternValidWireguardKey, props.validKeyError);

// Returns false when invalid
export const validateIpOrDomain = (
  val: string,
  allowMask = false,
  allowIPv6 = false,
): boolean => {
  return (
    (allowIPv6 && validateIPv6(val, allowMask)) ||
    validateIPv4(val, allowMask) ||
    patternValidDomain.test(val)
  );
};

// Returns false when invalid
export const validateIpList = (
  val: string,
  splitWith = ',',
  allowMasks = false,
): boolean => {
  return val
    .replace(' ', '')
    .split(splitWith)
    .every((el) => {
      return validateIPv4(el, allowMasks) || validateIPv6(el, allowMasks);
    });
};

// Returns false when invalid
export const validateIpOrDomainList = (
  val: string,
  splitWith = ',',
  allowMasks = false,
  allowIPv6 = false,
): boolean => {
  const trimmed = val.replace(' ', '');
  const split = trimmed.split(splitWith);
  for (const value of split) {
    if (
      !validateIPv4(value, allowMasks) &&
      !patternValidDomain.test(value) &&
      (!allowIPv6 || !validateIPv6(value, allowMasks))
    ) {
      return false;
    }
  }
  return true;
};

// Returns false when invalid
export const validateIPv4 = (ip: string, allowMask = false): boolean => {
  if (allowMask) {
    if (ip.includes('/')) {
      return ipaddr.IPv4.isValidCIDR(ip);
    }
  }
  return ipaddr.IPv4.isValid(ip);
};

export const validateIPv6 = (ip: string, allowMask = false): boolean => {
  if (allowMask) {
    if (ip.includes('/')) {
      return ipaddr.IPv6.isValidCIDR(ip);
    }
  }
  return ipaddr.IPv6.isValid(ip);
};

export const validatePort = (val: string) => {
  const parsed = parseInt(val, 10);
  if (!Number.isNaN(parsed)) {
    return parsed <= 65535;
  }
};

export const numericString = (val: string) => /^\d+$/.test(val);

export const numericStringFloat = (val: string) => /^\d*\.?\d+$/.test(val);
